#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_9_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ONEO_9_HPP_INCLUDED

#include <boost/simd/constant/include/constants/oneo_9.hpp>

#endif
